==> crypt-api-5.4-sources.jar: de/alpharogroup/crypto/key/KeyType.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.key;

import lombok.Getter;

/**
 * The enum {@link KeyType} can discriminate the type, if it is a private or public key or a
 * certificate.
 */
public enum KeyType
{

	/** The certificate type. */
	CERTIFICATE("Certificate"),

	/** The private key type. */
	PRIVATE_KEY("Private key"),

	/** The public key type. */
	PUBLIC_KEY("Public key");

	@Getter
	private final String displayValue;

	/**
	 * Instantiates a new {@link KeyType} object.
	 *
	 * @param displayValue
	 *            the display value
	 */
	private KeyType(final String displayValue)
	{
		this.displayValue = displayValue;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString()
	{
		return this.displayValue;
	}
}

==> crypt-api-5.8-sources.jar: de/alpharogroup/crypto/key/KeyType.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.key;

import lombok.Getter;

/**
 * The enum {@link KeyType} can discriminate the type, if it is a private or public key or a
 * certificate.
 */
public enum KeyType
{

	/** The certificate type. */
	CERTIFICATE("Certificate"),

	/** The private key type. */
	PRIVATE_KEY("Private key"),

	/** The password protected private key type. */
	PRIVATE_KEY_PASSWORD_PROTECTED("Password protected private key"),

	/** The public key type. */
	PUBLIC_KEY("Public key"),

	/** The password protected public key type. */
	PUBLIC_KEY_PASSWORD_PROTECTED("Password protected public key");

	@Getter
	private final String displayValue;

	/**
	 * Instantiates a new {@link KeyType} object.
	 *
	 * @param displayValue
	 *            the display value
	 */
	private KeyType(final String displayValue)
	{
		this.displayValue = displayValue;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString()
	{
		return this.displayValue;
	}
}
